#
# spec file for package python3-mpmath
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-mpmath
Version:        0.19
Release:        1.4
Summary:        Python library for arbitrary-precision floating-point arithmetic
License:        BSD-3-Clause
Group:          Development/Libraries/Python
Url:            http://mpmath.org
# THE *-all TARBALL CONTAINS SOURCE CODE + DOCUMENTATION
Source0:        http://mpmath.org/files/mpmath-all-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-gmpy  >= 1.03
BuildRequires:  python3-nose
BuildRequires:  python3-six
Requires:       python3-gmpy  >= 1.03
Requires:       python3-six
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Mpmath is a pure-Python library for multiprecision floating-point 
arithmetic. It provides an extensive set of transcendental functions, 
unlimited exponent sizes, complex numbers, interval arithmetic,
numerical integration and differentiation, root-finding, linear 
algebra, and much more. Almost any calculation can be performed just 
as well at 10-digit or 1000-digit precision, and in many cases mpmath
implements asymptotically fast algorithms that scale well for
extremely high precision work. If available, mpmath will (optionally) 
use gmpy to speed up high precision operations.

%prep
%setup -q -n mpmath-all-%{version}
sed -i 's/\r//' mpmath/tests/runtests.py  # fix wrong-script-end-of-line-encoding rpmlint warning
sed -i '1d' mpmath/tests/runtests.py  # fix non-executable-script rpmlint warning

%build
# CLEAN UP SHEBANGS FROM NON-EXEC FILES
for f in eigen eigen_symmetric
do
  sed -i '/\#!\/usr\/bin\/python/ d' mpmath/tests/test_${f}.py
  sed -i '/\#!\/usr\/bin\/python/ d' mpmath/matrices/${f}.py
done
sed -i '/\#!\/usr\/bin\/python/ d' mpmath/tests/test_levin.py
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
pushd demo
PYTHONPATH="%{buildroot}%{python3_sitelib}" python3 -B -c "import mpmath;mpmath.runtests()"
popd

%files
%defattr(-,root,root)
%doc CHANGES LICENSE README.rst
%{python3_sitelib}/*

%changelog
* Thu May 19 2016 toddrme2178@gmail.com
- Split documentation into own subpackage to speed up build.
* Fri Aug 14 2015 badshah400@gmail.com
- Update project and source URL's.
- Cleanup unnecessary shebangs for non-exec files.
* Thu Sep 18 2014 toddrme2178@gmail.com
- Initial python 3 version.
* Thu Sep 18 2014 toddrme2178@gmail.com
- Update to 0.19
  * Moved issue tracking to github and the main website to mpmath.org.
    Several URLs and issue numbers were updated in the documentation
    (Sergey B Kirpichev)
  * Enabled automatic testing with Travis CI (Sergey B Kirpichev)
  * Fixed many doctest issues (Sergey B Kirpichev)
  * Converted line endings to LF (Ondrej Certik)
  * Made polyroots() more robust (Ondrej Certik)
- Update to 0.18
  * Linear algebra:
  * added qr() for matrix QR factorization (contributed by Ken Allen)
  * added functions eigsy(), eighe(), eig() to compute matrix
    eigenvalues (contributed by Timo Hartmann)
  * added functions svd(), svd_r(), svd_c() for singular value
    decomposition of matrices (contributed by Timo Hartmann)
  * added calculation of Gaussian quadrature rules for various weight
    functions (contributed by Timo Hartmann)
  * improved precision selection in exp_pade() (contributed by
    Mario Pernici)
  * Special functions:
  * fixed ellippi() to return an inf instead of raising an exception
  * fixed a crash in zeta() with huge arguments
  * added functions for computing Stirling numbers
    (stirling1(), stirling2())
  * improved the computation of zeros of zeta at high precision
    (contributed by Juan Arias de Reyna)
  * fixed zeta(-x) raising an exception for tiny x
  * recognize when lerchphi() can call zeta() or polylog(),
    handling those cases faster
  * Compatibility:
  * fixed gmpy2 compatibility issues (contributed by Case Van Horsen)
  * better solutions for python 2/3 compatibility,
    using Benjamin Peterson's six.py
  * fixes to allow mpmath to run in non-sage mode when sage is available
  * support abstract base classes (contributed by Stefan Krastanov)
  * use new-style classes to improve pypy performance
  * Other:
  * added Levin, Sidi-S and Cohen/Villegas/Zagier series
    transformations (contributed by Timo Hartmann)
  * added isfinite() utility function
  * fixed a problem with bisection root-finding
  * fixed several documentation errors
  * corrected number of coefficients returned by diffs() with
    method='quad'
  * fixed repr(constant) being slow at high precision
  * made intervals hashable
- Run unit tests
* Tue Jan 31 2012 saschpe@suse.de
- Fix macro usage
- Set license to SPDX style (BSD-3-Clause)
- Package CHANGES, LICENSE and README
- Added group to doc package (SLE_11 build)
* Wed Jan  4 2012 toddrme2178@gmail.com
- version 0.17
- Cleaned up spec file formatting with spec-cleaner
- Changed source to point to upstream source URL
- Switched to .changes file
- Added documentation
* Sun Dec 20 2009 werner.ho@gmx.de
- fixed site-packages location for openSUSE 11.2
* Wed Jun 10 2009 felix.richter2@uni-rostock.de
- version 0.12
* Tue Jan  6 2009 felix.richter2@uni-rostock.de
- version 0.10
- directory fixes for opensuse 11.1
